import { world, system } from '@minecraft/server';

const bleedingLevels = [1, 2, 3];
const bleedingDuration = { 1: 30000, 2: 90000 }; const damagingMobs = [ 'minecraft:zombie', 'minecraft:husk', 'minecraft:drowned', 'minecraft:skeleton', 'minecraft:stray', 'minecraft:wither_skeleton', 'minecraft:pillager', 'minecraft:vindicator', 'minecraft:ravager', 'minecraft:warden' ];

function applyBleedingEffect(entity) { const bleedingTag = entity.getTags().find(tag => tag.startsWith("bleeding_")); const bleedingLevel = bleedingTag ? parseInt(bleedingTag.split("_")[1]) : null;

if (bleedingLevel && bleedingLevels.includes(bleedingLevel)) {
    entity.runCommandAsync(`effect @s wither 3 ${bleedingLevel - 1} false`);
    let message = "You are bleeding!";
    if (bleedingLevel === 2) message = "You are heavily bleeding!";
    if (bleedingLevel === 3) message = "You are critically bleeding!";
    
    entity.runCommandAsync(`title @s title §c${message}`);
    const repeatCount = Math.pow(2, bleedingLevel - 1);
    const { x, y, z } = entity.location;

    for (let i = 0; i < repeatCount; i++) {
        entity.runCommandAsync(`particle la:blood ${x} ${y + 1} ${z}`);
    }

    if (bleedingLevel < 3) {
        system.runTimeout(() => {
            if (entity.isValid() && entity.getTags().includes(`bleeding_${bleedingLevel}`)) {
                if (Math.random() < (bleedingLevel === 1 ? 0.3 : 0.2)) {
                    const nextLevel = bleedingLevel + 1;
                    entity.addTag(`bleeding_${nextLevel}`);
                    entity.runCommandAsync(`say §cThe bleeding worsened!`);
                } else {
                    entity.removeTag(`bleeding_${bleedingLevel}`);
                    entity.runCommandAsync(`title @s title §aBleeding stopped!`);
                    entity.runCommandAsync(`particle minecraft:heart_particle ~ ~ ~`);
                }
            }
        }, bleedingDuration[bleedingLevel] / 50);
    }
}

}

world.afterEvents.entityHitEntity.subscribe((data) => { const { damagingEntity, hitEntity } = data;

if (!damagingEntity || !hitEntity) return;
if (!damagingMobs.includes(damagingEntity.typeId)) return;

const tags = hitEntity.getTags();
if (tags.includes("bleeding_2") || tags.includes("bleeding_3")) return;

if (Math.random() < 0.05) {
    hitEntity.addTag('bleeding_1');
}

});

system.runInterval(() => { const overworld = world.getDimension("overworld"); for (const entity of overworld.getEntities({})) { if (entity.getTags().some(tag => tag.startsWith("bleeding_"))) { applyBleedingEffect(entity); } } }, 20);

