import { world } from "@minecraft/server";

const scoreboardList = [
    { id: "kutsu", score: 0 }
];

function getScoreUtility(entity, objectiveId) {
    try {
        const objective = world.scoreboard.getObjective(objectiveId);
        if (!objective) return 0;

        return objective.getScore(entity) || 0;
    } catch {
        return 0;
    }
}

function setScoreUtility(entity, objectiveId, score) {
    try {
        const objective = world.scoreboard.getObjective(objectiveId);
        if (objective) {
            objective.setScore(entity, score);
        }
    } catch {}
}

function fixScoreUtility(entity, objectiveId, score) {
    if (getScoreUtility(entity, objectiveId) !== score) {
        setScoreUtility(entity, objectiveId, score);
    }
}

function operationScoreUtility(entity, objectiveId, scoreChange) {
    try {
        const currentScore = getScoreUtility(entity, objectiveId);
        setScoreUtility(entity, objectiveId, currentScore + scoreChange);
    } catch {}
}

const excludedEntities = [
    "minecraft:wither",
    "minecraft:ender_dragon"
];

world.afterEvents.entityHitEntity.subscribe((eventData) => {
    const { damagingEntity, hitEntity } = eventData;

    if (damagingEntity.typeId !== "minecraft:player") return;

    if (!damagingEntity.hasTag("kutsu")) return;

    if (excludedEntities.includes(hitEntity.typeId)) return;

    const kutsuScore = getScoreUtility(damagingEntity, "kutsu");
    if (kutsuScore < 30) {
        damagingEntity.runCommand("say No kutsu!");
        return;
    }

    // 10%
    if (Math.random() < 0.1) {
        damagingEntity.runCommand("tag @s add kutsufinisher");
        hitEntity.runCommand("function kutsu");
    } else {
        damagingEntity.runCommand("tag @s add kutsuimune");
        damagingEntity.runCommand("playanimation @s Kutsu.punch");
        hitEntity.runCommand("function Kutsu/kutsu");
        damagingEntity.runCommand("tag @s remove kutsuimune");
    }
});

export { getScoreUtility, setScoreUtility, fixScoreUtility, operationScoreUtility, scoreboardList };