import { world } from '@minecraft/server';
const selectedEntities = [
    "minecraft:zombie",
    "minecraft:skeleton",
    "minecraft:creeper",
    "minecraft:spider",
    "minecraft:enderman",
    "minecraft:witch",
    "minecraft:slime",
    "minecraft:cave_spider",
    "minecraft:husk",
    "minecraft:stray",
    "minecraft:drowned",
    "minecraft:blaze"
];

const levelTagsWithProbabilities = [
    { tag: "level_1", probability: 50 },
    { tag: "level_2", probability: 20 },
    { tag: "level_3", probability: 10 },
    { tag: "level_4", probability: 8 },
    { tag: "level_5", probability: 5 },
    { tag: "level_6", probability: 3 },
    { tag: "level_7", probability: 2 }, 
    { tag: "level_8", probability: 1 },
    { tag: "level_9", probability: 0.9 },
    { tag: "level_10", probability: 0.1 }
];

function getRandomLevelTag() {
    const random = Math.random() * 100;
    let cumulativeProbability = 0;

    for (const { tag, probability } of levelTagsWithProbabilities) {
        cumulativeProbability += probability;
        if (random <= cumulativeProbability) {
            return tag;
        }
    }

    return null;
}

world.afterEvents.entitySpawn.subscribe((data) => {
    const { entity } = data;

    if (selectedEntities.includes(entity.typeId)) {
        const existingTags = entity.getTags();
        existingTags.forEach(tag => {
            if (tag.startsWith("level_")) {
                entity.runCommand(`tag @s remove ${tag}`);
            }
        });

        const randomTag = getRandomLevelTag();
        if (randomTag) {
            entity.runCommand(`tag @s add ${randomTag}`);
        }
    }
});