import { world } from '@minecraft/server';

const cooldowns = {};

function canUseCommand(player, tag, cooldownTime) {
    const playerName = player.name;

    if (!cooldowns[playerName]) {
        cooldowns[playerName] = {};
    }

    const currentTime = Date.now();
    const lastUsedTime = cooldowns[playerName][tag] || 0;

    if (currentTime - lastUsedTime >= cooldownTime) {
        cooldowns[playerName][tag] = currentTime;
        return true;
    }

    return false;
}

function hasItemInInventory(player, itemId) {
    const inventory = player.getComponent('minecraft:inventory').container;
    for (let i = 0; i < inventory.size; i++) {
        const item = inventory.getItem(i);
        if (item && item.typeId === itemId) {
            return true;
        }
    }
    return false;
}

function sendCooldownMessage(player) {
    player.runCommandAsync(`title @s actionbar §0COOLDOWN`);
}

world.afterEvents.itemUse.subscribe((eventData) => {
    const player = eventData.source;
    const item = eventData.itemStack.typeId;

    const tagCooldowns = {
        "skill1": 9000, //Sovereignstyle
        "skill1_alt": 9000,
        "skill2": 10000,
        "skill3": 7000,
        "skill4": 9000,
        "skill3V": 100000,
        "skill5": 300000,
        "skill6": 300000,
        "skill1eye": 20000, //Eyeless
        "skill2eye": 17000,
        "skill3eye": 25000,
        "skill4eye": 2400,
        "skill5eye": 800000,
        "skill6eye": 450000,
        "skill1sh": 9000, //Shredderwolf
        "skill2sh": 2000,
        "skill3sh": 20000,
        "skill4sh": 9000,
        "skill5sh": 300000
    };

    switch (item) {
        case "la:sovereignstyle":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:sovereignstyle")) {
                if (player.hasTag("skill1")) {
                    if (player.hasTag("sovereign")) {
                        if (canUseCommand(player, "skill1_alt", tagCooldowns["skill1_alt"])) {
                            player.runCommand('tag @s add cataclysmic_blow');
                            return;
                        } else {
                            sendCooldownMessage(player);
                        }
                    } else {
                        if (!player.hasTag("cataclysmic_blow")) {
                            let randomChance = Math.random();
                            if (randomChance < 0.08) {
                                player.runCommand('tag @s add cataclysmic_blow');
                                return;
                            }
                        }
            
                        if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                            player.runCommand('tag @s add sovereigncrushing');
                        } else {
                            sendCooldownMessage(player);
                        }
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('tag @s add punchbarrage');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (player.hasTag("shift")) {
                        if (canUseCommand(player, "skill3V", tagCooldowns["skill3V"])) {
                            player.runCommand('tag @s add sovereignmeteor');
                        } else {
                            sendCooldownMessage(player);
                        }
                    } else {
                        if (canUseCommand(player, "skill3V", tagCooldowns["skill3V"])) {
                            player.runCommand('tag @s add deathstrike');
                        } else {
                            sendCooldownMessage(player);
                        }
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('tag @s add sovereignimpale');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill6")) {
                    let hasRequiredLevel = false;
                    for (let i = 8; i <= 20; i++) {
                        if (player.hasTag(`level_${i}`)) {
                            hasRequiredLevel = true;
                            break;
                        }
                    }
                
                    if (hasRequiredLevel) {
                        if (player.hasTag("sovereigntyform")) {
                            if (canUseCommand(player, "skill6_alt", tagCooldowns["skill6_alt"])) {
                                player.runCommand('tag @s add cataclysmic_blow');
                            } else {
                                sendCooldownMessage(player);
                            }
                        } else {
                            if (canUseCommand(player, "skill6", tagCooldowns["skill6"])) {
                                player.runCommand('tag @s add sovereigntyform');
                            } else {
                                sendCooldownMessage(player);
                            }
                        }
                    } else {
                        player.runCommand('tell @s "I need to be above level 8 to use this skill."');
                    }
                }
                if (player.hasTag("skill5")) {
                    let hasRequiredLevel = false;
                    for (let i = 5; i <= 30; i++) {
                        if (player.hasTag(`level_${i}`)) {
                            hasRequiredLevel = true;
                            break;
                        }
                    }
                
                    if (hasRequiredLevel) {
                        if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                            player.runCommand('tag @s add ult_sovereign');
                        } else {
                            sendCooldownMessage(player);
                        }
                    } else {
                        player.runCommand('tell @s "I need to be above level 5 to use this skill."');
                    }
                }
            }
            break;
        case "la:masterofmarbles":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:masterofmarbles")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/Masterofmarbles/masterofmarbles');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/Masterofmarbles/masterofmarbles');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/Masterofmarbles/masterofmarbles');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/Masterofmarbles/masterofmarbles');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (player.hasTag("level_5")) {
                        if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                            player.runCommand('tag @s add ult_marbles');
                        } else {
                            sendCooldownMessage(player);
                        }
                    } else {
                        player.runCommand('tell @s "i need to be at level 5 to use this skill."');
                    }
                }
            }
            break;
        case "la:shredderwolf":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:shredderwolf")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/Shredderwolf/shredderwolf');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2sh"])) {
                        player.runCommand('tag @s add clawinvade');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3sh"])) {
                        player.runCommand('function Movesets/Shredderwolf/shredderwolf');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/Shredderwolf/shredderwolf');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_wolf');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:elementalemperor":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:elementalemperor")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/ElementalEmperor/elementalemperor');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/ElementalEmperor/elementalemperor');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/ElementalEmperor/elementalemperor');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/ElementalEmperor/elementalemperor');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_elemental');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:poisonwitch":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:poisonwitch")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/PoisonWitch/poisonwitch');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/PoisonWitch/poisonwitch');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/PoisonWitch/poisonwitch');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/PoisonWitch/poisonwitch');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_witch');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:icedevil":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:icedevil")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/IceDevil/icedevil');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/IceDevil/icedevil');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/IceDevil/icedevil');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/IceDevil/icedevil');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_ice');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:theyu01":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:theyu01")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/TheYu01/theyu01');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/TheYu01/theyu01');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/TheYu01/theyu01');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/TheYu01/theyu01');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_yu01');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:eyeless":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:eyeless")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1eye"])) {
                        player.runCommand('tag @s add darkdome');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2eye"])) {
                        player.runCommand('function Movesets/Eyeless/eyeless');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3eye"])) {
                        player.runCommand('function Movesets/Eyeless/eyeless');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4eye"])) {
                        player.runCommand('function Movesets/Eyeless/eyeless');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill6")) {
                    if (canUseCommand(player, "skill6", tagCooldowns["skill6eye"])) {
                        player.runCommand('tag @s add ult_eyeless');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (player.hasTag("level_5")) {
                        if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                            player.runCommand('tag @s add ult_sovereign');
                        } else {
                            sendCooldownMessage(player);
                        }
                    } else {
                        player.runCommand('tell @s "i need to be at level 5 to use this skill."');
                    }
                }
            }
            break;
        case "la:starqueen":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:starqueen")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/StarQueen/starqueen');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/StarQueen/starqueen');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/StarQueen/starqueen');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/StarQueen/starqueen');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_starqueen');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:thunderking":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:thunderking")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/ThunderKing/thunderking');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/ThunderKing/thunderking');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/ThunderKing/thunderking');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/ThunderKing/thunderking');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_thunderking');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:vampiriclegacy":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:vampiriclegacy")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/VampiricLegacy/vampiriclegacy');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/VampiricLegacy/vampiriclegacy');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/VampiricLegacy/vampiriclegacy');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/VampiricLegacy/vampiriclegacy');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_vampire');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:steeldragon":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:steeldragon")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/SteelDragon/steeldragon');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/SteelDragon/steeldragon');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/SteelDragon/steeldragon');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/SteelDragon/steeldragon');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_dragon');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:gholthsprincess":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:gholthsprincess")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/GholthsPrincess/gholthsprincess');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/GholthsPrincess/gholthsprincess');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/GholthsPrincess/gholthsprincess');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/GholthsPrincess/gholthsprincess');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_princess');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:the3thousandshadows":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:the3thousandshadows")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/The3thousandShadows/the3thousandshadows');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/The3thousandShadows/the3thousandshadows');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/The3thousandShadows/the3thousandshadows');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/The3thousandShadows/the3thousandshadows');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_3thousand');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:lightlord":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:lightlord")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/Lightlord/lightlord');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/Lightlord/lightlord');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/Lightlord/lightlord');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/Lightlord/lightlord');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_light');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
        case "la:greatstyle":
        case "minecraft:diamond_sword":
        case "minecraft:netherite_sword":
        case "minecraft:iron_sword":
        case "minecraft:golden_sword":
        case "minecraft:mace":
        case "minecraft:stone_sword":
            if (hasItemInInventory(player, "la:greatstyle")) {
                if (player.hasTag("skill1")) {
                    if (canUseCommand(player, "skill1", tagCooldowns["skill1"])) {
                        player.runCommand('function Movesets/GreatStyle/greatstyle');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill2")) {
                    if (canUseCommand(player, "skill2", tagCooldowns["skill2"])) {
                        player.runCommand('function Movesets/GreatStyle/greatstyle');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill3")) {
                    if (canUseCommand(player, "skill3", tagCooldowns["skill3"])) {
                        player.runCommand('function Movesets/GreatStyle/greatstyle');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill4")) {
                    if (canUseCommand(player, "skill4", tagCooldowns["skill4"])) {
                        player.runCommand('function Movesets/GreatStyle/greatstyle');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
                if (player.hasTag("skill5")) {
                    if (canUseCommand(player, "skill5", tagCooldowns["skill5"])) {
                        player.runCommand('tag @s add ult_great');
                    } else {
                        sendCooldownMessage(player);
                    }
                }
            }
            break;
    }
});
   // "sovereignstyle" Mafangs
   // "masterofmarbles" Kaiuham
   // "shredderwolf" Trust
   // "poisonwitch" Melion
   // "elementalemperor" Bochezi
   // "icedevil" Carlos
   // "theyu01" Yu01
   // "eyeless" Darck/Eyeless
   // "starqueen" Manhi
   // "thunderking" Zoro
   // "vampiriclegacy" Kendak
   // "steeldragon" Sorha
   // "gholthsprincess" Moryu
   // "the3thousandshadows" Zai/Kallebres
   // "lightlord" Roblinho
   // "greatstyle" Kallebe
