import { world } from '@minecraft/server';

const cooldowns = {};

function canUseCommand(player, tag, cooldownTime) {
    const playerName = player.name;

    if (!cooldowns[playerName]) {
        cooldowns[playerName] = {};
    }

    const currentTime = Date.now();
    const lastUsedTime = cooldowns[playerName][tag] || 0;

    if (currentTime - lastUsedTime >= cooldownTime) {
        cooldowns[playerName][tag] = currentTime;
        return true;
    }

    return false;
}

function hasItemInInventory(player, itemId) {
    const inventory = player.getComponent('minecraft:inventory').container;
    for (let i = 0; i < inventory.size; i++) {
        const item = inventory.getItem(i);
        if (item && item.typeId === itemId) {
            return true;
        }
    }
    return false;
}

world.afterEvents.itemUse.subscribe((eventData) => {
    const player = eventData.source;
    const item = eventData.itemStack.typeId;

    const tagCooldowns = {
        "dash": 2000,
        "target": 0
    };
    switch (item) {
        case "la:movimentation":
            if (hasItemInInventory(player, "la:movimentation")) {
                if (player.hasTag("start")) {
                    if (canUseCommand(player, "dash", tagCooldowns["dash"])) {
                        const playerName = player.nameTag.toLowerCase();
                        const targetTag = `${playerName}_target`;
                        const targets = world.getDimension('overworld').getEntities({ tags: [targetTag] });
        
                        if (targets.length > 0) {
                            player.addTag("teleport");
                        } else {
                            player.runCommand('summon la:dash ^^2^-10');
                        }
                    }
                }
            }
            break;
        case "la:sovereignstyle_learn":
            if (hasItemInInventory(player, "la:sovereignstyle_learn")) {
                if (player.hasTag("start")) {
                    if (canUseCommand(player, "dash", tagCooldowns["dash"])) {
                        player.runCommand('replaceitem entity @s slot.hotbar 7 la:sovereignstyle 1 0 {"minecraft:item_lock":{"mode":"lock_in_slot"}}');
                        player.runCommand('clear @s la:sovereignstyle_learn 0 1');
                    }
                }
            }
            break;
        case "minecraft:nether_star":
            if (hasItemInInventory(player, "minecraft:nether_star")) {
                if (player.hasTag("start")) {
                    if (canUseCommand(player, "dash", tagCooldowns["dash"])) {
                        let level = getScore(player, "level");
                        let statPoints = getScore(player, "statPoints");
                        let strength = getScore(player, "strength");
                        let health = getScore(player, "health");
                        let basePoints = level * 2;
                        setScore(player, "statPoints", basePoints);
                        setScore(player, "strength", 0);
                        setScore(player, "health", 0);
                        for (let i = 0; i <= 20; i++) {
                            player.removeTag(`strength_${i}`);
                            player.removeTag(`health_${i}`);
                        }
                        player.sendMessage("§cYour points have been reset! You now have §b" + basePoints + "§c stat points.");
                        player.runCommand('clear @s nether_star 0 1');
                        updateHUD(player);
                    }
                }
            }
            break;
        case "la:stats":
            if (hasItemInInventory(player, "la:stats")) {
                if (player.hasTag("start")) {
                    if (canUseCommand(player, "dash", tagCooldowns["dash"])) {
                        player.runCommand('replaceitem entity @s slot.hotbar 8 la:stats 1 0 {"minecraft:item_lock":{"mode":"lock_in_slot"}}');
        
                        if (player.hasTag("stats_ing")) {
                            player.runCommand('tag @s remove stats_ing');
                        } else {
                            player.runCommand('tag @s add stats_ing');
                        }
                    }
                }
            }
            break;
        case "la:bandages":
            if (hasItemInInventory(player, "la:bandages")) {
                if (player.hasTag("start")) {
                    if (canUseCommand(player, "dash", tagCooldowns["dash"])) {
                        if (player.hasTag("bleeding_3") || player.hasTag("bleeding_2") || player.hasTag("bleeding_1")) {
                            let failureChance = 0;
        
                            if (player.hasTag("bleeding_1")) failureChance = 0.1;
                            if (player.hasTag("bleeding_2")) failureChance = 0.25;
                            if (player.hasTag("bleeding_3")) failureChance = 0.75;
        
                            if (Math.random() < failureChance) {
                                player.runCommand("say §cThe bandages failed to stop the bleeding!");
                                player.runCommand('clear @s la:bandages 0 1');
                            } else {
                                player.runCommand('tag @s remove bleeding_3');
                                player.runCommand('tag @s remove bleeding_2');
                                player.runCommand('tag @s remove bleeding_1');
                                player.runCommand('execute as @s at @s run particle minecraft:totem_particle ~ ~1 ~');
                                player.runCommand('title @s title §aBleeding stopped!');
                                player.runCommand('clear @s la:bandages 0 1');
                            }
                        } else {
                            player.runCommand("say I don't need to use this.");
                        }
                    }
                }
            }
            break;
        case "la:target_maker":
            if (hasItemInInventory(player, "la:target_maker")) {
                if (player.hasTag("start")) {
                    if (canUseCommand(player, "target", tagCooldowns["target"])) {
                        player.runCommand('execute as @s at @s run tag @e[c=1,type=!player] add target');
                        player.runCommand('execute as @s at @e[r=5,c=1,type=!player] run particle minecraft:totem_particle ~~1~');
                        player.runCommand('execute as @s at @e[r=5,c=1,type=!player] run particle minecraft:totem_particle ~~1~');
                    }
                }
            }
            break
    }
});