import { world, system } from "@minecraft/server";

system.runInterval(() => {
    const players = world.getPlayers();

    players.forEach(player => {
        if (player.isSneaking) {
            const playerName = player.nameTag.toLowerCase();
            const targetTag = `${playerName}_target`;
            const targets = world.getDimension('overworld').getEntities({ tags: [targetTag] });

            if (targets.length > 0) {
                const target = targets[0];
                if (target.isValid()) {
                    player.teleport(target.location, { dimension: target.dimension });
                    player.runCommand(`particle minecraft:portal ${target.location.x} ${target.location.y} ${target.location.z}`);
                    player.runCommand(`particle minecraft:portal ${player.location.x} ${player.location.y} ${player.location.z}`);
                    target.removeTag(targetTag);
                }
            } else {
                player.runCommand("execute as @s at @s[rx=-70,rxm=-90] run function Features/skillchange");
                player.runCommand("execute as @s at @s[rx=90,rxm=80] run function Sword/swordskillchange");
                player.runCommand("function Kutsu/kutsu_recharge");
                player.runCommand("tag @s add shift");
            }
        } else {
            player.runCommand("tag @s remove shift");
        }

        if (hasItemInInventory(player, "la:sovereignstyle")) {
            player.runCommand(`particle la:sovereignaure ${player.location.x} ${player.location.y} ${player.location.z}`);
            player.runCommand(`summon la:sovereignkick ${player.location.x} ${player.location.y} ${player.location.z}`);
            player.runCommand(`playanimation @s animation.Mafangs.kick`);
        }
    });
}, 10);

function hasItemInInventory(player, itemId) {
    const inventory = player.getComponent("minecraft:inventory").container;
    for (let i = 0; i < inventory.size; i++) {
        const item = inventory.getItem(i);
        if (item && item.id === itemId) {
            return true;
        }
    }
    return false;
}