import { world, system } from "@minecraft/server";

function onMafangsDeath(event) {
  const entity = event.deadEntity;
  if (entity.typeId === "la:mafangs") {
    const players = world.getPlayers();
    for (const player of players) {
      player.runCommand("function Movesets/Sovereignstyle/sovereignstyle_get");
    }
  }
}
world.afterEvents.entityDie.subscribe(onMafangsDeath);

// Dano base
const ultBaseDamage1 = 1;
const ultBaseDamage2 = 2;
const ultBaseDamage3 = 20;
const baseDamagebloodyMimic = 20;
const baseDamageImpale = 1;
const baseDamageSovereignImpact = 12;
const baseDamagePunchBarrage = 1;
const BASE_DAMAGE_CATACLYSMIC_BLOW = 35;

function getEntityDimension(entity) {
  return world.getDimension(entity.dimension.id);
}
function getStrengthValue(entity) {
  const scoreboard = world.scoreboard.getObjective("strength");
  if (scoreboard) {
    const score = scoreboard.getScore(entity);
    return score || 0;
  }
  return 0;
}
function getScaledDamage(entity, baseDamage) {
  const strengthValue = getStrengthValue(entity);
  return baseDamage + (strengthValue * 2);
}

function getFinalDamage(entity) {
  return getScaledDamage(entity, baseDamagebloodyMimic);
}

const ultimateSovereignScores = new Map();

function incrementUltimateSovereign(entity) {
  const score = ultimateSovereignScores.get(entity) || 0;
  ultimateSovereignScores.set(entity, score + 1);
}

function resetUltimateSovereign(entity) {
  ultimateSovereignScores.delete(entity);
  entity.runCommand(`tag @s remove ult_sovereign`);
  entity.runCommand(`scoreboard players reset @s ultimatesovereign`);
}

function processUltimateSovereign(entity, score) {
  if (score === 1) {
    entity.runCommand(`tag @s add player`);
    entity.runCommand(`playanimation @s animation.mafangs.ultimate J 14`);
    entity.runCommand(`camera @s set minecraft:free ease 0 in_out_back pos ^3^0.5^-2 facing @s`);
  } else if (score === 4) {
    entity.runCommand(`particle la:sovereign_thunder_explosion`);
  } else if (score === 5) {
    entity.runCommand(`particle la:break_particle`);
    entity.runCommand(`camerashake add @a[r=20] 4 1 positional`);
    entity.runCommand(`damage @e[r=19,tag=!ult_sovereign] ${getScaledDamage(entity, ultBaseDamage1)}`);
    entity.runCommand(`effect @e[r=20] slowness 14 9`);
    entity.runCommand(`effect @e[r=20] weakness 14 255`);
  } else if (score === 10) {
    entity.runCommand(`particle la:break_particle`);
    entity.runCommand(`playsound sovereignIm @a[r=35]`);
    entity.runCommand(`particle la:sovereign_thunder_explosion`);
    entity.runCommand(`camerashake add @a[r=20] 4 1 positional`);
    entity.runCommand(`damage @e[r=19,tag=!ult_sovereign] ${getScaledDamage(entity, ultBaseDamage1)}`);
  } else if (score === 30 || score === 50) {
    entity.runCommand(`particle la:break_particle`);
    entity.runCommand(`playsound sovereignIm @a[r=35]`);
    entity.runCommand(`particle la:sovereign_thunder_explosion`);
    entity.runCommand(`camerashake add @a[r=20] 4 1 positional`);
    entity.runCommand(`damage @e[r=19,tag=!ult_sovereign] ${getScaledDamage(entity, ultBaseDamage1)}`);
    if (score === 50) {
      entity.runCommand(`camera @s set minecraft:free ease 0 in_out_back pos ^^3^2 facing @s`);
    }
  } else if (score === 70) {
    entity.runCommand(`particle la:sovereign_thunder_explosion`);
    entity.runCommand(`playsound sovereignIm @a[r=35]`);
    entity.runCommand(`particle la:break_particle`);
    entity.runCommand(`camerashake add @a[r=20] 4 1 positional`);
    entity.runCommand(`damage @e[r=19,tag=!ult_sovereign] ${getScaledDamage(entity, ultBaseDamage1)}`);
  } else if (score === 90) {
    entity.runCommand(`particle la:break_particle`);
    entity.runCommand(`playsound sovereignIm @a[r=35]`);
    entity.runCommand(`camerashake add @a[r=20] 4 1 positional`);
    entity.runCommand(`particle la:sovereign_thunder_explosion`);
    entity.runCommand(`damage @e[r=40,tag=!ult_sovereign] ${getScaledDamage(entity, ultBaseDamage1)}`);
  } else if (score === 120) {
    entity.runCommand(`camerashake add @a[r=20] 4 5 positional`);
    entity.runCommand(`playsound sovereignIm @a[r=35]`);
    entity.runCommand(`particle la:sovereign_thunder_explosion`);
    entity.runCommand(`damage @e[r=19,tag=!ult_sovereign] ${getScaledDamage(entity, ultBaseDamage2)}`);
    entity.runCommand(`effect @e[r=40] slow_falling 35 20`);
    entity.runCommand(`effect @e[r=40] invisibility 35 20`);
    entity.runCommand(`particle la:dash_particle`);
    entity.runCommand(`summon la:mafangsultimate`);
  } else if (score === 150) {
    entity.runCommand(`camera @a[r=100] set minecraft:free ease 0 in_out_back pos ~19~70~-19 facing @s`);
  } else if (score === 370) {
    entity.runCommand(`tag @s add ult_sovereign2`);
    entity.runCommand(`effect @s clear`);
    entity.runCommand(`tp @e[r=50,tag=!ult_sovereign,type=la:mafangsultimate] ~~-70~`);
    entity.runCommand(`particle la:sovereign_explosion`);
  } else if (score === 410) {
    entity.runCommand(`particle la:area_dust_particle ~~~`);
    entity.runCommand(`playsound groundIm @a[r=150]`);
    entity.runCommand(`kill @e[r=120,tag=!ult_sovereign,type=la:mafangsultimate]`);
  } else if (score === 430) {
    entity.runCommand(`particle la:dust_particle ~~~`);
    entity.runCommand(`particle la:sovereign_explosion2`);
    entity.runCommand(`camerashake add @a[r=20] 4 1 positional`);
    entity.runCommand(`damage @e[r=100,tag=!ult_sovereign] ${getScaledDamage(entity, ultBaseDamage3)}`);
    entity.runCommand(`camera @a[r=60] set minecraft:free ease 0 in_expo pos ^^2^3 facing @s`);
    entity.runCommand(`playanimation @s animation.mafangs.finisherult`);
    entity.runCommand(`tag @e[r=30,tag=!ult_sovereign] add bleeding_1`);
    entity.runCommand(`playsound groundIm @a[r=150]`);
    entity.runCommand(`tag @s add ultimatesovereigndes`);
    entity.runCommand(`effect @e[r=20] slowness 20 20`);
  } else if (score > 480) {
    entity.runCommand(`camera @a[r=100] clear`);
    entity.runCommand(`tag @s remove ult_sovereign`);
    entity.runCommand(`tag @s remove ult_sovereign2`);
    resetUltimateSovereign(entity);
  }
  if (score >= 150 && score <= 350) {
    entity.runCommand(`camerashake add @a[r=100] 1 1 positional`);
    entity.runCommand(`damage @e[r=60,tag=!ult_sovereign,type=!la:mafangsultimate] ${getScaledDamage(entity, ultBaseDamage1)}`);
    entity.runCommand(`effect @e[r=20] slowness 14 9`);
    entity.runCommand(`tp @e[r=50,type=la:mafangsultimate] ~~30~`);
    entity.runCommand(`effect @e[r=20] weakness 14 255`);
    entity.runCommand(`tp @e[r=40,tag=!ult_sovereign] ~~30~`);
  }

  if (score >= 370 && score <= 450) {
    entity.runCommand(`particle sovereign_thunder_ultimate`);
    entity.runCommand(`tp @e[r=50,tag=!ult_sovereign] ~~30~`);
  }
}

system.runInterval(() => {
  const dimensions = [
    world.getDimension("overworld"),
    world.getDimension("nether"),
    world.getDimension("the_end")
  ];

  dimensions.forEach(dimension => {
    const entities = dimension.getEntities({
      tags: ["ult_sovereign"],
    });

    entities.forEach((entity) => {
      incrementUltimateSovereign(entity);
      const score = ultimateSovereignScores.get(entity);

      processUltimateSovereign(entity, score);

      if (score > 480) {
        resetUltimateSovereign(entity);
      }
    });
  });
}, 0.09);

// Bloody Mimic
const deathstrikeScores = new Map();

function incrementDeathstrike(entity) {
  const score = deathstrikeScores.get(entity) || 0;
  deathstrikeScores.set(entity, score + 1);
}

function processDeathstrike(entity, score) {
  const finalDamage = getFinalDamage(entity);

  if (score === 15) {
    entity.runCommand(`playanimation @s animation.mafangs_mimic`);
    entity.runCommand(`effect @s[tag=deathstrike,r=10] levitation 1 20`);
    entity.runCommand(`effect @s slow_falling 10 255`);
    entity.runCommand(`camerashake add @a[r=20] 4 1 positional`);
    entity.runCommand(`camera @s fade time 0 0 1`);
    entity.runCommand(`damage @e[r=3,tag=!deathstrike] 5`);
    entity.runCommand(`particle la:charged_jump_strike`);
  } else if (score >= 20 && score <= 50) {
    entity.runCommand(`particle la:deathpoint ^^1^1`);
  } else if (score === 60) {
    entity.runCommand(`effect @e[r=4,tag=!deathstrike] levitation 2 20`);
    entity.runCommand(`particle la:sovereign_thunder_explosion`);
    entity.runCommand(`damage @e[r=3,tag=!deathstrike] ${finalDamage}`);
    entity.runCommand(`particle minecraft:large_explosion ^^1^1`);
    entity.runCommand(`camera @s clear`);
  } else if (score === 20) {
    entity.runCommand(`effect @s[tag=deathstrike,r=10] levitation 1 20`);
    entity.runCommand(`effect @s levitation 1 255`);
    entity.runCommand(`camerashake add @a[r=20] 4 1 positional`);
    entity.runCommand(`camera @s fade time 0 0 1`);
    entity.runCommand(`damage @e[r=3,tag=!deathstrike] 5`);
    entity.runCommand(`particle la:charged_jump_strike`);
  } else if (score >= 55 && score <= 65) {
    entity.runCommand(`particle la:sovereign_deathimpact ^^1^1`);
  }

  if (score >= 5 && score <= 59) {
    entity.runCommand(`tp @e[r=4,tag=!deathstrike,c=1] ^^1^1`);
  }

  if (score > 60) {
    entity.runCommand(`tag @s remove deathstrike`);
    deathstrikeScores.delete(entity);
  }
}

system.runInterval(() => {
  const dimensions = [
    world.getDimension("overworld"),
    world.getDimension("nether"),
    world.getDimension("the_end")
  ];

  dimensions.forEach(dimension => {
    const entities = [
      ...dimension.getPlayers({ tags: ["deathstrike"] }),
      ...dimension.getEntities({ type: "la:mafangs", tags: ["deathstrike"] }),
    ];

    entities.forEach((entity) => {
      incrementDeathstrike(entity);
      const score = deathstrikeScores.get(entity);

      processDeathstrike(entity, score);
    });
  });
}, 0.3);

// Imperial Falls
const sovereignImpaleScores = new Map();

function incrementSovereignImpale(entity) {
  const score = sovereignImpaleScores.get(entity) || 0;
  sovereignImpaleScores.set(entity, score + 1);
}

function resetSovereignImpale(entity) {
  sovereignImpaleScores.delete(entity);
  entity.runCommand("tag @s remove sovereignimpale");
  entity.runCommand("scoreboard players reset @s sovereignimpale");
}

function processSovereignImpale(entity, score) {
  const scaledDamage = getScaledDamage(entity, baseDamageImpale);

  if (score === 1) {
    entity.runCommand("playsound wind @a[r=30]");
    entity.runCommand("particle la:sovereign_thunder_explosion_low");
    entity.runCommand("playanimation @s animation.mafangs.impale J 5");
    entity.runCommand("summon la:dash_sovereign_impale ^^^-1");
  }

  if (score >= 1 && score <= 15) {
    entity.runCommand("tag @e[r=6,tag=!sovereignimpale] add impaled");
    entity.runCommand(`damage @e[r=70,tag=impaled] ${scaledDamage}`);
    entity.runCommand("summon la:sovereignstyle_knockback ~~~");
  }

  if (score === 50) {
    entity.runCommand("tag @e[r=500] remove impaled");
    entity.runCommand("camera @s clear");
    resetSovereignImpale(entity);
  }
}

function clearImpaledBlocks() {
  const dimensions = [
    world.getDimension("overworld"),
    world.getDimension("nether"),
    world.getDimension("the_end")
  ];

  dimensions.forEach(dimension => {
    const impaledEntities = dimension.getEntities({ tags: ["impaled"] });

    const blocksToReplace = [
      "ice", "water", "acacia_leaves", "azalea_leaves", "oak_leaves", "dark_oak_leaves",
      "birch_leaves", "mangrove_leaves", "jungle_leaves", "cherry_leaves", "spruce_leaves",
      "packed_ice", "glass"
    ];

    impaledEntities.forEach(entity => {
      blocksToReplace.forEach(block => {
        entity.runCommand(`fill ~-1 ~-1 ~-1 ~1 ~3 ~1 air replace ${block}`);
      });
      entity.runCommand("fill ~-1 ~-1 ~-1 ~1 ~1 ~1 dirt replace grass_block");
    });
  });
}

system.runInterval(() => {
  const dimensions = [
    world.getDimension("overworld"),
    world.getDimension("nether"),
    world.getDimension("the_end")
  ];

  dimensions.forEach(dimension => {
    const entities = dimension.getEntities({ tags: ["sovereignimpale"] });

    entities.forEach(entity => {
      incrementSovereignImpale(entity);
      const score = sovereignImpaleScores.get(entity);
      processSovereignImpale(entity, score);

      if (score > 50) {
        resetSovereignImpale(entity);
      }
    });
  });

  clearImpaledBlocks();
}, 0.09);

// Sovereign Crushing
const SovereignImpactScores = new Map();

function incrementSovereignImpact(entity) {
  const score = SovereignImpactScores.get(entity) || 0;
  SovereignImpactScores.set(entity, score + 1);
}

function processSovereignImpact(entity, score) {
  entity.runCommand("tag @s add resistance");
  const damage = getScaledDamage(entity, baseDamageSovereignImpact);
  entity.runCommand(`damage @e[tag=!resistance,r=10] ${damage}`);
  entity.runCommand("effect @e[tag=!resistance,r=10] levitation 1 20");
  entity.runCommand("tag @s remove resistance");

  const particles = [
    "minecraft:large_explosion ~~2~",
    "minecraft:explosion_particle ~~2~",
    "minecraft:large_explosion ~3~~3",
    "minecraft:explosion_particle ~-3~~-3",
    "minecraft:large_explosion ~5~2~4",
    "minecraft:explosion_particle ~~2~1",
    "minecraft:large_explosion ~4~~5",
    "minecraft:explosion_particle ~-1~~-2",
    "la:sovereign_impact ~~~",
    "la:sovereign_ground_impact",
    "la:sovereign_thunder_explosion"
  ];

  particles.forEach(particle => entity.runCommand(`particle ${particle}`));

  const blockChanges = [
    "fill ~1~-1~1 ~-1~2~-1 dirt_with_roots replace grass",
    "fill ~3~-1~ ~3~2~ dirt_with_roots replace grass",
    "fill ~-3~-1~ ~-3~2~ dirt_with_roots replace grass",
    "fill ~-3~-1~2 ~-3~2~2 dirt_with_roots replace grass"
  ];

  blockChanges.forEach(command => entity.runCommand(command));

  entity.runCommand("camerashake add @a[r=20] 2 1 positional");
  entity.runCommand("playsound sovereignIm @a[r=20]");
  entity.runCommand("playanimation @s animation.mafangs.ground_impact");

  SovereignImpactScores.delete(entity);
  entity.runCommand("tag @s remove sovereigncrushing");
}

system.runInterval(() => {
  const dimensions = [
    world.getDimension("overworld"),
    world.getDimension("nether"),
    world.getDimension("the_end")
  ];

  dimensions.forEach(dimension => {
    const entities = [
      ...dimension.getPlayers({ tags: ["sovereigncrushing"] }),
      ...dimension.getEntities({ type: "la:mafangs", tags: ["sovereigncrushing"] }),
    ];

    entities.forEach((entity) => {
      incrementSovereignImpact(entity);
      const score = SovereignImpactScores.get(entity);

      processSovereignImpact(entity, score);
    });
  });
}, 0.3);

// Punch Barrage
const punchbarrageScores = new Map();

function calculateDamage(baseDamagePunchBarrage, entity) {
  const strengthValue = getStrengthValue(entity);
  return baseDamagePunchBarrage + (strengthValue * 3);
}

function incrementPunchBarrage(entity) {
  const score = punchbarrageScores.get(entity) || 0;
  punchbarrageScores.set(entity, score + 1);
}

function resetPunchBarrage(entity) {
  punchbarrageScores.delete(entity);
  entity.runCommand(`tag @s remove punchbarrage`);
  entity.runCommand(`scoreboard players reset @s punchbarrage`);
}

function processPunchBarrage(entity, score) {
  const finalDamage = calculateDamage(baseDamagePunchBarrage, entity);

  if (score >= 1) {
    entity.runCommand(`playsound sovereignIm @a[r=30]`);
    entity.runCommand(`particle la:sovereign_thunder_explosion_low`);
  }

  if (score === 1) {
    entity.runCommand(`playanimation @s animation.mafangs.punchs a 5`);
  }

  if ([5, 12, 19, 26, 33, 40].includes(score)) {
    entity.runCommand(`effect @e[r=4] slowness 1 5`);
    entity.runCommand(`damage @e[r=3,tag=!punchbarrage] ${finalDamage}`);
    entity.runCommand(`particle minecraft:large_explosion ^^1^1`);
    entity.runCommand(`particle minecraft:explosion_particle ^^1^1`);
  }

  if (score === 40) {
    const strongDamage = calculateDamage(15, entity);
    entity.runCommand(`damage @e[r=3,tag=!punchbarrage] ${strongDamage}`);
    entity.runCommand(`tag @e[r=30,tag=!punchbarrage] add bleeding_1`);
    entity.runCommand(`particle minecraft:large_explosion ^^1^`);
    entity.runCommand(`particle minecraft:explosion_particle ^1^1^`);
    entity.runCommand(`particle minecraft:large_explosion ^1^1^`);
    entity.runCommand(`particle minecraft:explosion_particle ^^1^1`);
    entity.runCommand(`particle la:sovereignaure_charge`);
  }

  if (score === 50) {
    entity.runCommand(`camera @s clear`);
    resetPunchBarrage(entity);
  }
}

system.runInterval(() => {
  const dimensions = [
    world.getDimension("overworld"),
    world.getDimension("nether"),
    world.getDimension("the_end")
  ];

  dimensions.forEach(dimension => {
    const entities = dimension.getEntities({
      tags: ["punchbarrage"],
    });

    entities.forEach((entity) => {
      incrementPunchBarrage(entity);
      const score = punchbarrageScores.get(entity);

      processPunchBarrage(entity, score);

      if (score > 50) {
        resetPunchBarrage(entity);
      }
    });
  });
}, 0.09);

// Second Form & Ultimate
const ENTITY_ID = "la:mafangs";
const MAX_BAR_VALUE = 250;
const MAX_ULTIMATE_VALUE = 150;
const MAX_RAGE_VALUE = 450;
const DIALOGUE_INTERVAL = 70;

const entityBars = new Map();
const ultimateBars = new Map();
const rageBars = new Map();
const dialogueThresholds = new Map();

world.afterEvents.entityHitEntity.subscribe((data) => {
  const { damagingEntity, hitEntity } = data;

  if (damagingEntity.typeId !== ENTITY_ID) return;

  const entityId = damagingEntity.id;

  if (!entityBars.has(entityId)) {
    entityBars.set(entityId, 0);
    dialogueThresholds.set(entityId, DIALOGUE_INTERVAL);
  }
  if (!ultimateBars.has(entityId)) {
    ultimateBars.set(entityId, 0);
  }
  if (!rageBars.has(entityId)) {
    rageBars.set(entityId, 0);
  }

  const currentBarValue = entityBars.get(entityId) + 10;
  entityBars.set(entityId, currentBarValue);

  const currentUltimateValue = ultimateBars.get(entityId) + 2;
  ultimateBars.set(entityId, currentUltimateValue);

  const currentRageValue = rageBars.get(entityId) + 8;
  rageBars.set(entityId, currentRageValue);

  let currentThreshold = dialogueThresholds.get(entityId);
  if (currentBarValue >= currentThreshold) {
    dialogueThresholds.set(entityId, currentThreshold + DIALOGUE_INTERVAL);
    triggerDialogue(currentBarValue, damagingEntity);
  }

  if (currentBarValue >= MAX_BAR_VALUE && !damagingEntity.hasTag("secondform")) {
    damagingEntity.addTag("secondform");
    world.sendMessage(`<Mafangs - §4The Sovereign> §fYou can never beat me...`);
    world.sendMessage(`<Mafangs - §4The Sovereign> §fLet's take this seriously now...`);
    entityBars.set(entityId, 0);
    dialogueThresholds.set(entityId, DIALOGUE_INTERVAL);
  }

  if (currentUltimateValue >= MAX_ULTIMATE_VALUE && !damagingEntity.hasTag("ult_sovereign")) {
    damagingEntity.addTag("ult_sovereign");
    ultimateBars.set(entityId, 0);
  }

  if (currentRageValue >= MAX_RAGE_VALUE && !damagingEntity.hasTag("rage_mode")) {
    damagingEntity.addTag("rage_mode");
    world.sendMessage(`<Mafangs - §4The Sovereign> §fSubmit to sover...`);
    damagingEntity.runCommand(`effect @s instant_health 1 30`);
    world.sendMessage(`<Mafangs - §4The §5Sovereign> §fNo...`);
    world.sendMessage(`<Mafangs - §4The Monarch> §fSubmit to §5Monarch!`);
    rageBars.set(entityId, 0);
  }
});

function triggerDialogue(value, entity) {
  const dialogues = [
    "You're getting on my nerves...",
    "Is that all you've got?",
    "Pathetic...",
    "You are wasting my time.",
    "You think you stand a chance?",
    "This is only the beginning...",
    "I will show you true power of one §aBrazilian§f!"
  ];

  const index = Math.min(Math.floor(value / DIALOGUE_INTERVAL), dialogues.length - 1);
  const title = entity.hasTag("rage_mode") ? "The Monarch" : "The Sovereign";
  world.sendMessage(`<Mafangs - §4${title}> §f${dialogues[index]}`);
}

// Sovereign Meteor
const sovereignMeteorScores = new Map();

function incrementSovereignMeteor(entity) {
  const score = sovereignMeteorScores.get(entity) || 0;
  sovereignMeteorScores.set(entity, score + 1);
}

function isEntityAboveGround(entity, maxHeight) {
  const { x, y, z } = entity.location;
  const dimension = getEntityDimension(entity);

  for (let i = 0; i <= maxHeight; i++) {
    const blockBelow = dimension.getBlock({
      x: Math.floor(x),
      y: Math.floor(y) - i - 1,
      z: Math.floor(z),
    });

    if (blockBelow && blockBelow.typeId !== "minecraft:air") {
      return true;
    }
  }
  return false;
}

function destroyBlocksInCircle(entity, destructionRadius, maxBlocks, minVerticalRange, maxVerticalRange) {
  let blocksDestroyed = 0;
  const dimension = getEntityDimension(entity);

  for (let x = -destructionRadius; x <= destructionRadius; x++) {
    for (let z = -destructionRadius; z <= destructionRadius; z++) {
      const distance = Math.sqrt(x * x + z * z);
      if (distance <= destructionRadius && Math.random() > 0.3) {
        const verticalRange = Math.floor(Math.random() * (maxVerticalRange - minVerticalRange + 1)) + minVerticalRange;
        for (let y = -verticalRange; y <= verticalRange; y++) {
          try {
            const block = dimension.getBlock({
              x: Math.floor(entity.location.x) + x,
              y: Math.floor(entity.location.y) + y,
              z: Math.floor(entity.location.z) + z,
            });

            if (block && block.typeId !== "minecraft:bedrock") {
              dimension.setBlockType({
                x: Math.floor(entity.location.x) + x,
                y: Math.floor(entity.location.y) + y,
                z: Math.floor(entity.location.z) + z,
              }, "minecraft:air");
              blocksDestroyed++;
              if (blocksDestroyed >= maxBlocks) return;
            }
          } catch (e) {}
        }
      }
    }
  }

  entity.removeTag("sovereignmeteor");
}

function processSovereignMeteor(entity, score) {
  const baseDamage = 4;
  const baseRadiusDamage = 2;
  const baseRadius = 1;
  const multiplier = 1.5;
  const multiplierdamage = 2;

  if (score === 1) {
    entity.runCommand(`effect @s levitation 1 80`);
    entity.runCommand(`effect @s slowness 30 3`);
    entity.runCommand(`camerashake add @a[r=20] 4 1 positional`);
  }

  if (isEntityAboveGround(entity, 10)) {
    entity.runCommand(`effect @s slow_falling 1 1 true`);
  }

  if (score >= 60 && isEntityAboveGround(entity, 0)) {
    const impactRadius = baseRadius * Math.pow(2, score / 60) * multiplier;
    const damageRadius = baseRadiusDamage * Math.pow(2, score / 60) * multiplierdamage;
    const damage = baseDamage * Math.pow(2, score / 60) * multiplierdamage;

    entity.runCommand(`particle la:sovereign_thunder_explosion ~~~`);
    entity.runCommand(`damage @e[r=${damageRadius},tag=!sovereignmeteor] ${damage}`);

    const minVerticalRange = Math.floor(Math.random() * 3) + 2;
    const maxVerticalRange = minVerticalRange + 5;
    destroyBlocksInCircle(entity, Math.floor(impactRadius), 40000, minVerticalRange, maxVerticalRange);

    entity.runCommand(`tag @s remove sovereignmeteor`);
    sovereignMeteorScores.delete(entity);
  }
}

system.runInterval(() => {
  const dimensions = [
    world.getDimension("overworld"),
    world.getDimension("nether"),
    world.getDimension("the_end")
  ];

  dimensions.forEach(dimension => {
    const entities = [
      ...dimension.getPlayers({ tags: ["sovereignmeteor"] }),
      ...dimension.getEntities({ type: "la:mafangs", tags: ["sovereignmeteor"] }),
    ];

    entities.forEach((entity) => {
      incrementSovereignMeteor(entity);
      const score = sovereignMeteorScores.get(entity);

      processSovereignMeteor(entity, score);
    });
  });
}, 0.3);

// Mafangs
function performSequence(entity) {
  if (entity.hasTag("mafangspg")) return;

  entity.runCommand(`tag @s add mafangspg`);

  system.runTimeout(() => {
    entity.runCommand(`tellraw @a[r=50] {"rawtext":[{"text":"<Mafangs> Who dares to invade my territory..."}]}`);
  }, 0);

  system.runTimeout(() => {
    entity.runCommand(`tellraw @a[r=50] {"rawtext":[{"text":"<Mafangs> But whatever, I was already moving...","color":"yellow"}]}`);
  }, 50);

  system.runTimeout(() => {
    entity.runCommand(`tellraw @a[r=50] {"rawtext":[{"text":"<Mafangs> So... Let's destroy §4EVERYTHING!","color":"dark_red"}]}`);
  }, 100);

  for (let i = 100; i < 170; i += 1) {
    system.runTimeout(() => {
      entity.runCommand(`particle la:sovereignaure ~1 ~ ~`);
      entity.runCommand(`particle la:sovereignaure ~-1 ~ ~`);
      entity.runCommand(`particle la:sovereignaure ~ ~1 ~`);
      entity.runCommand(`particle la:sovereignaure ~ ~-1 ~`);
      entity.runCommand(`particle la:sovereignaure ~ ~ ~1`);
      entity.runCommand(`particle la:sovereignaure ~ ~ ~-1`);
      entity.runCommand(`particle la:sovereignaure ~~~`);
    }, i);
  }

  system.runTimeout(() => {
    for (let i = 0; i < 2; i++) {
      entity.runCommand(`particle la:sovereign_thunder_explosion ~~~`);
      entity.runCommand(`particle la:sovereignaure ~1~1~`);
      entity.runCommand(`particle la:sovereignaure ~-1~-1~`);
      entity.runCommand(`particle la:sovereignaure ~2~~2`);
      entity.runCommand(`particle la:sovereignaure ~-2~~-2`);
    }
    entity.runCommand(`camerashake add @a[r=50] 1 4 positional`);

    const destructionRadius = 45;
    const destructionDepth = 2;
    let blocksDestroyed = 0;
    const maxBlocks = 15000;

    for (let x = -destructionRadius; x <= destructionRadius; x++) {
      for (let z = -destructionRadius; z <= destructionRadius; z++) {
        if (Math.random() < 0.2 && blocksDestroyed < maxBlocks) {
          for (let y = 0; y > -destructionDepth; y--) {
            entity.runCommand(`setblock ~${x} ~${y} ~${z} minecraft:air`);
          }
          blocksDestroyed++;
        }
      }
    }

    entity.runCommand(`summon la:mafangs ~~~`);
    entity.runCommand(`kill @s`);
  }, 160);

  system.runTimeout(() => {
    entity.runCommand(`tag @s remove mafangspg`);
  }, 500);
}

system.runInterval(() => {
  const dimensions = [
    world.getDimension("overworld"),
    world.getDimension("nether"),
    world.getDimension("the_end")
  ];

  dimensions.forEach(dimension => {
    const entities = dimension.getEntities({
      type: "la:mafangs_statue",
      tags: ["statuemafangs"],
    });

    entities.forEach((entity) => {
      performSequence(entity);
    });
  });
}, 1);

// Cataclysmic Blow
const cataclysmicBlowScores = new Map();
const blowedPlayers = new Set();

function incrementCataclysmicBlow(entity) {
  const score = cataclysmicBlowScores.get(entity) || 0;
  cataclysmicBlowScores.set(entity, score + 1);
}

function removeBlowedTag(entity) {
  if (blowedPlayers.has(entity.id)) {
    entity.runCommand("tag @s remove blowed");
    blowedPlayers.delete(entity.id);
  }
}

function calculateDamageBlow(entity, score) {
  const strengthValue = getStrengthValue(entity);
  return BASE_DAMAGE_CATACLYSMIC_BLOW + (strengthValue * 4) + (score * 4);
}

function processCataclysmicBlow(entity, score) {
  const damageBlow = calculateDamageBlow(entity, score);
  const dimension = getEntityDimension(entity);

  if (score >= 1 && score <= 10) {
    entity.runCommand("camera @a[r=60] set minecraft:free ease 0 in_expo pos ^-1^0.5^2 facing @s");
    entity.runCommand("particle la:sovereignaure_monarcky ~~~");
    entity.runCommand("effect @e[r=500,tag=blowed] slowness 3 60");
    entity.runCommand("title @a[r=20] actionbar §r§5Cataclysmic...");
    entity.runCommand("effect @s slowness 3 60");
    entity.runCommand("playanimation @s animation.mafangs.cataclysmic_blow");
  } else if (score >= 10 && score <= 20) {
    entity.runCommand("camera @a[r=60] set minecraft:free ease 0 in_expo pos ^^3^-4 facing @s");
    entity.runCommand("particle la:sovereignaure_monarcky ~~~");
    entity.runCommand("effect @e[r=500,tag=blowed] slowness 3 60");
  }

  if (score === 39) {
    entity.runCommand("summon la:cataclysmic_blow ^^^");
    entity.runCommand("title @a[r=20] actionbar §r§4blow...");
    entity.runCommand("effect @e[r=500,tag=blowed] slowness 3 60");
    entity.runCommand("camera @a[r=20] fade time 0 1 1 color 255 0 200");
    entity.runCommand("playsound charge @a[r=45]");
    entity.runCommand("particle la:sovereign_point_explosion ~~~");
    entity.runCommand("effect @e[r=500,tag=blowed] levitation 2 60");
    entity.runCommand("effect @s slowness 3 60");
    entity.runCommand("camerashake add @a[r=20] 4 1 positional");
    entity.runCommand(`damage @e[r=3,tag=!cataclysmic_blow] ${damageBlow}`);
    entity.runCommand("tag @e[r=8,tag=!cataclysmic_blow,type=!la:cataclysmic_blow] add blowed");
    entity.runCommand("particle la:cataclysmic_punch_aura");

    const particles = ["p", "p"];
    particles.forEach(particle => entity.runCommand(`particle ${particle}`));

    const blockChanges = [
      "fill ~1~-1~1 ~-1~2~-1 dirt_with_roots replace grass",
      "fill ~3~-1~ ~3~2~ dirt_with_roots replace grass",
      "fill ~-3~-1~ ~-3~2~ dirt_with_roots replace grass",
      "fill ~-3~-1~2 ~-3~2~2 dirt_with_roots replace grass"
    ];
    blockChanges.forEach(command => entity.runCommand(command));

    const affectedEntities = dimension.getEntities({ tags: ["blowed"] });
    affectedEntities.forEach(ent => {
      if (!blowedPlayers.has(ent.id)) {
        blowedPlayers.add(ent.id);
        system.runTimeout(() => removeBlowedTag(ent), 50);
      }
    });
  } else if (score >= 15 && score <= 50) {
    entity.runCommand("execute as @e[tag=blowed] at @s run effect @s levitation 1 70");
  } else if (score === 80) {
    entity.runCommand("camera @a clear");
  }
  if (score === 50) {
    entity.runCommand("tag @e[r=200] remove blowed");
  }
  if (score >= 120) {
    entity.runCommand("tag @e[r=200] remove blowed");
    entity.runCommand("kill @e[type=la:cataclysmic_blow,r=200]");
  }

  if (score >= 120) {
    entity.runCommand("tag @s remove cataclysmic_blow");
    entity.runCommand("tag @e[r=200] remove blowed");
    cataclysmicBlowScores.delete(entity);
  }
}

system.runInterval(() => {
  const dimensions = [
    world.getDimension("overworld"),
    world.getDimension("nether"),
    world.getDimension("the_end")
  ];

  dimensions.forEach(dimension => {
    const entities = [
      ...dimension.getPlayers({ tags: ["cataclysmic_blow"] }),
      ...dimension.getEntities({ type: "la:mafangs", tags: ["cataclysmic_blow"] }),
    ];

    entities.forEach((entity) => {
      incrementCataclysmicBlow(entity);
      const score = cataclysmicBlowScores.get(entity);
      processCataclysmicBlow(entity, score);
    });
  });
}, 1);