import { world, system } from "@minecraft/server";

const xpDrop = {
    "minecraft:zombie": 10, 
    "minecraft:skeleton": 15, 
    "minecraft:creeper": 20, 
    "minecraft:witch": 30, 
    "minecraft:enderman": 40,
    "minecraft:blaze": 50,
    "minecraft:ghast": 60,
    "minecraft:guardian": 70,
    "minecraft:elder_guardian": 350,
    "minecraft:pillager": 25,
    "minecraft:vindicator": 35,
    "minecraft:wither_skeleton": 50,
    "minecraft:rabbit": 5,
    "minecraft:silverfish": 10,
    "minecraft:slime": 20,
    "minecraft:magma_cube": 25,
    "minecraft:spider": 15,
    "minecraft:cave_spider": 18,
    "minecraft:drowned": 20,
    "minecraft:husk": 18,
    "minecraft:stray": 22,
    "minecraft:ravager": 200,
    "minecraft:phantom": 30,
    "minecraft:piglin": 20,
    "minecraft:piglin_brute": 40,
    "minecraft:zombified_piglin": 25,
    "minecraft:hoglin": 30,
    "minecraft:shulker": 60,
    "minecraft:snow_golem": 10,
    "minecraft:iron_golem": 260,
    "minecraft:goat": 8,
    "minecraft:turtle": 6,
    "minecraft:axolotl": 12,
    "minecraft:glow_squid": 10,
    "minecraft:camel": 12,
    "minecraft:sniffer": 25,
    "minecraft:mooshroom": 15,
    "minecraft:allay": 16,
    "minecraft:ocelot": 10,
    "minecraft:parrot": 8,
    "minecraft:wolf": 12,
    "minecraft:fox": 12,
    "minecraft:polar_bear": 25,
    "minecraft:frog": 6,
    "minecraft:warden": 1000, 
    "minecraft:wither": 1500, 
    "minecraft:ender_dragon": 3000,
    "la:mafangs": 19500,
    "la:runic_guard": 1940,
    "minecraft:bat": 3,
    "minecraft:evoker": 85,
    "minecraft:bee": 8,
    "minecraft:cat": 10,
    "minecraft:chicken": 4,
    "minecraft:cod": 2,
    "minecraft:cow": 6,
    "minecraft:donkey": 10,
    "minecraft:dolphin": 15,
    "minecraft:endermite": 12,
    "minecraft:horse": 12,
    "minecraft:llama": 10,
    "minecraft:mule": 10,
    "minecraft:panda": 15,
    "minecraft:pig": 5,
    "minecraft:pufferfish": 5,
    "minecraft:salmon": 2,
    "minecraft:sheep": 6,
    "minecraft:squid": 10,
    "minecraft:strider": 15,
    "minecraft:trader_llama": 10,
    "minecraft:tropical_fish": 2,
    "minecraft:zoglin": 40,
};

const xpRequiredByLevel = [
    500, 1500, 3500, 4500, 6000, 7500, 9000, 11000, 13000, 15000,
    17500, 20000, 22500, 25000, 27500, 30000, 32500, 35000, 37500, 40000
];

const maxLevel = 20;

function setupScoreboards() {
    let objectives = ["xp", "level", "statPoints", "strength", "health"];
    for (let obj of objectives) {
        try {
            if (!world.scoreboard.getObjective(obj)) {
                world.scoreboard.addObjective(obj, obj);
            }
        } catch (e) {}
    }
}

function getScore(player, objective) {
    let obj = world.scoreboard.getObjective(objective);
    return obj ? obj.getScore(player) || 0 : 0;
}

function setScore(player, objective, value) {
    let obj = world.scoreboard.getObjective(objective);
    if (obj) {
        obj.setScore(player, value);
    }
}

function xpNeeded(level) {
    if (level <= maxLevel) {
        return xpRequiredByLevel[level - 1];
    }
    return 0;
}

function updateHUD(player) {
    if (!player.hasTag("stats_ing")) return;

    let xp = getScore(player, "xp");
    let level = getScore(player, "level");
    let statPoints = getScore(player, "statPoints");
    let strength = getScore(player, "strength");
    let health = getScore(player, "health");
    let mode = player.hasTag("strength_choice") ? "strength" : "health";
    let modeColor = mode === "strength" ? "§c" : "§a";

    player.onScreenDisplay.setActionBar(
        `§eXP: §b${xp}\n` +
        `§6Level: §b${level}\n` +
        `§dStat Points: §b${statPoints}\n` +
        `§cStrength: §b${strength}\n` +
        `§aHealth: §b${health}\n` +
        `${modeColor}${mode.toUpperCase()} MODE\n` +
        `§7Hold §eShift§7 to switch mode\n` +
        `§7Press §bJump§7 to upgrade`
    );
}

function checkLevelUp(player) {
    let xp = getScore(player, "xp");
    let level = getScore(player, "level");

    while (xp >= xpNeeded(level + 1) && level < maxLevel) {
        xp -= xpNeeded(level + 1);
        level++;
        setScore(player, "xp", xp);
        setScore(player, "level", level);

        let statPoints = getScore(player, "statPoints");
        setScore(player, "statPoints", statPoints + 2);

        player.removeTag(`level_${level - 1}`);
        player.addTag(`level_${level}`);

        player.sendMessage(`§a🎉 Congratulations! You've reached Level §b${level}§a!`);
        player.sendMessage(`§6You gained 2 stat points! Use for your upgrades.`);

        updateHUD(player);
    }
}

function getNearbyPlayers(centerPlayer, radius) {
    const players = [];
    for (const player of world.getPlayers()) {
        const distance = Math.sqrt(
            Math.pow(player.location.x - centerPlayer.location.x, 2) +
            Math.pow(player.location.y - centerPlayer.location.y, 2) +
            Math.pow(player.location.z - centerPlayer.location.z, 2)
        );
        if (distance <= radius) {
            players.push(player);
        }
    }
    return players;
}

world.afterEvents.entityDie.subscribe(event => {
    const { deadEntity } = event;
    let baseXp = xpDrop[deadEntity.typeId] || 10;
    let xpGained = Math.floor(baseXp * 1);
    
    const nearbyPlayers = getNearbyPlayers(deadEntity, 20);
    if (nearbyPlayers.length === 0) return;

    const xpPerPlayer = Math.floor(xpGained / nearbyPlayers.length);
    
    for (const player of nearbyPlayers) {
        let currentXp = getScore(player, "xp");
        setScore(player, "xp", currentXp + xpPerPlayer);
        player.sendMessage(`§a+${xpPerPlayer} XP gained!`);
        checkLevelUp(player);
    }
});
function resetPlayer(player) {
    setScore(player, "xp", 0);
    setScore(player, "level", 0);
    setScore(player, "statPoints", 0);
    setScore(player, "strength", 0);
    setScore(player, "health", 0);

    for (let i = 0; i <= maxLevel; i++) {
        player.removeTag(`level_${i}`);
    }

    player.removeTag("strength_choice");
    player.removeTag("health_choice");

    for (let i = 0; i <= 20; i++) {
        player.removeTag(`strength_${i}`);
        player.removeTag(`health_${i}`);
    }

    player.addTag("level_0");

    player.sendMessage("§cAll your stats have been reset!");
    updateHUD(player);
}

function checkForReset(player) {
    if (player.hasTag("reset_all")) {
        resetPlayer(player);
        player.removeTag("reset_all");
    }
}

world.afterEvents.playerJoin.subscribe(event => {
    let player = event.player;

    setupScoreboards();

    checkForReset(player);

    updateHUD(player);
});

system.runInterval(() => {
    for (let player of world.getPlayers()) {
        updateHUD(player);
        checkForReset(player);
    }
}, 20);

system.runInterval(() => {
    for (let player of world.getPlayers()) {
        if (player.hasTag("stats_ing") && player.isSneaking) {
            let mode = player.hasTag("strength_choice") ? "strength" : "health";
            let newMode = mode === "strength" ? "health" : "strength";

            player.sendMessage(`§aSwitched to§6 ${newMode.charAt(0).toUpperCase() + newMode.slice(1)} Mode!`);
            player.removeTag(`${mode}_choice`);
            player.addTag(`${newMode}_choice`);
        }
    }
}, 20);

function isPlayerInAir(player) {
    const dimension = player.dimension;
    const blockBelow = dimension.getBlock({ x: player.location.x, y: player.location.y - 1, z: player.location.z });
    return blockBelow?.typeId === "minecraft:air";
}

system.runInterval(() => {
    for (let player of world.getPlayers()) {
        if (isPlayerInAir(player) && player.hasTag("stats_ing")) {
            let statPoints = getScore(player, "statPoints");

            if (statPoints > 0) {
                let strength = getScore(player, "strength");
                let health = getScore(player, "health");

                if (player.hasTag("strength_choice")) {
                    setScore(player, "strength", strength + 1);
                    player.sendMessage(`§aYou added a point to §cStrength!§a Your §cStrength §ais now  ${strength + 1}.`);

                    player.addTag(`strength_${strength + 1}`);
                    if (strength > 0) {
                        player.removeTag(`strength_${strength}`);
                    }
                } else {
                    setScore(player, "health", health + 1);
                    player.sendMessage(`§6You added a point to §aHealth! §6Your §aHealth§6 is now ${health + 1}.`);

                    player.addTag(`health_${health + 1}`);
                    if (health > 0) {
                        player.removeTag(`health_${health}`);
                    }
                }

                setScore(player, "statPoints", statPoints - 1);
                updateHUD(player);
            } else {
                player.sendMessage("§cYou don't have any stat points to spend.");
            }
        }
    }
}, 20);

system.runInterval(() => {
    for (const player of world.getAllPlayers()) {
        const strength = getScore(player, "strength");
        const health = getScore(player, "health");

        if (strength > 0) {
            const strengthLevel = Math.floor(strength / 5);
            const amplifier = Math.min(strengthLevel, 255);
            player.addEffect("strength", 200, { amplifier: amplifier, showParticles: false });
        }

        if (health > 0) {
            const healthLevel = health * 2;
            const amplifier = Math.min(healthLevel, 255);
            player.addEffect("health_boost", 200, { amplifier: amplifier, showParticles: false });
        }
    }
}, 1);